Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Providers []provider.Name
// ApiAddress only used by [Http] client, setting its value for [Local] client won't destroy the world, but it's pointless.
// defaults to (https://api.danklyrics.com)
ApiAddress string
}
Config holds the configs needed to initialize Local or Http clients.
type Http ¶
type Http struct {
// contains filtered or unexported fields
}
Http is the dank lyrics finding client that makes a call to api.danklyrics.com to find the lyrics.
func (*Http) GetSongLyrics ¶
GetSongLyrics search for song's lyrics using the enabled providers list, where using a provider depends on the provider's order in that list.
returns [Lyrics] and an occurring [error]
type Local ¶
type Local struct {
// contains filtered or unexported fields
}
Local is the dank lyrics finding client that uses finder.Service to find lyrics using the enabled providers.
func (*Local) GetSongLyrics ¶
GetSongLyrics search for song's lyrics using the enabled providers list, where using a provider depends on the provider's order in that list.
returns [Lyrics] and an occurring [error]